skalibs: the kolbak library interface
Keywords: skalibs c kolbak library libunixonacid

libunixonacid
libskarnet
skalibs
Software
skarnet.org

# The `kolbak` library interface

The following functions are declared in the `skalibs/kolbak.h` header, and implemented in the `libskarnet.a` or `libskarnet.so` library.

## General information

`kolbak` implements simple queuing of callback functions to use when sending a message to a peer and expecting an answer, which will be handled by the callback function. The queue is a circular buffer.

FIXME: To be completed.